@@ -12,12 +12,11 @@ import org.torproject.onionoo.docs.DocumentStoreFactory;
 import org.torproject.onionoo.docs.SummaryDocument;
 import org.torproject.onionoo.docs.UptimeDocument;
 import org.torproject.onionoo.docs.WeightsDocument;
+import org.torproject.onionoo.util.FormattingUtils;
 
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
 
-import org.apache.commons.lang3.StringUtils;
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -123,7 +122,7 @@ public class ResponseBuilder {
     return this.charsWritten;
   }
 
-  private static final String PROTOCOL_VERSION = "5.1";
+  private static final String PROTOCOL_VERSION = "5.2";
 
   private static final String NEXT_MAJOR_VERSION_SCHEDULED = "2018-04-14";
 
@@ -340,6 +339,8 @@ public class ResponseBuilder {
                 detailsDocument.getUnreachableOrAddresses());
           } else if (field.equals("version")) {
             dd.setVersion(detailsDocument.getVersion());
+          } else if (field.equals("version_status")) {
+            dd.setVersionStatus(detailsDocument.getVersionStatus());
           }
         }
         /* Don't escape HTML characters, like < and >, contained in
@@ -348,7 +349,7 @@ public class ResponseBuilder {
         /* Whenever we provide Gson with a string containing an escaped
          * non-ASCII character like \u00F2, it escapes the \ to \\, which
          * we need to undo before including the string in a response. */
-        return StringUtils.replace(gson.toJson(dd), "\\\\u", "\\u");
+        return FormattingUtils.replaceValidUtf(gson.toJson(dd));
       } else {
         // TODO We should probably log that we didn't find a details
         // document that we expected to exist.
