@@ -1,4 +1,4 @@
-/* Copyright 2011--2017 The Tor Project
+/* Copyright 2011--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.onionoo.cron;
@@ -22,8 +22,7 @@ import java.util.concurrent.TimeUnit;
 /* Update search data and status data files. */
 public class Main implements Runnable {
 
-  private Main() {
-  }
+  private Main() {}
 
   private Logger log = LoggerFactory.getLogger(Main.class);
 
